@@ -1,18 +1,35 @@
 //! `os_info`
 //!
 //! Provides interfaces for getting information about the current operating system, such as type,
-//! version and edition.
+//! version, edition and bitness.
 
-#![deny(missing_debug_implementations, missing_docs, unsafe_code)]
+#![deny(
+    missing_debug_implementations,
+    missing_docs,
+    unsafe_code,
+    missing_doc_code_examples
+)]
 
 #[cfg(target_os = "android")]
 #[path = "android/mod.rs"]
 mod imp;
 
+#[cfg(target_os = "dragonfly")]
+#[path = "dragonfly/mod.rs"]
+mod imp;
+
 #[cfg(target_os = "emscripten")]
 #[path = "emscripten/mod.rs"]
 mod imp;
 
+#[cfg(target_os = "freebsd")]
+#[path = "freebsd/mod.rs"]
+mod imp;
+
+#[cfg(target_os = "illumos")]
+#[path = "illumos/mod.rs"]
+mod imp;
+
 #[cfg(target_os = "linux")]
 #[path = "linux/mod.rs"]
 mod imp;
@@ -21,6 +38,14 @@ mod imp;
 #[path = "macos/mod.rs"]
 mod imp;
 
+#[cfg(target_os = "netbsd")]
+#[path = "netbsd/mod.rs"]
+mod imp;
+
+#[cfg(target_os = "openbsd")]
+#[path = "openbsd/mod.rs"]
+mod imp;
+
 #[cfg(target_os = "redox")]
 #[path = "redox/mod.rs"]
 mod imp;
@@ -31,9 +56,14 @@ mod imp;
 
 #[cfg(not(any(
     target_os = "android",
+    target_os = "dragonfly",
     target_os = "emscripten",
+    target_os = "freebsd",
+    target_os = "illumos",
     target_os = "linux",
     target_os = "macos",
+    target_os = "netbsd",
+    target_os = "openbsd",
     target_os = "redox",
     target_os = "windows"
 )))]
@@ -42,13 +72,20 @@ mod imp;
 
 mod bitness;
 mod info;
+#[cfg(not(windows))]
+mod matcher;
 mod os_type;
+#[cfg(any(
+    target_os = "dragonfly",
+    target_os = "freebsd",
+    target_os = "illumos",
+    target_os = "netbsd",
+    target_os = "openbsd"
+))]
+mod uname;
 mod version;
 
-pub use bitness::Bitness;
-pub use info::Info;
-pub use os_type::Type;
-pub use version::{Version, VersionType};
+pub use crate::{bitness::Bitness, info::Info, os_type::Type, version::Version};
 
 /// Returns information about the current operating system (type, version, edition, etc.).
 ///
@@ -65,6 +102,8 @@ pub use version::{Version, VersionType};
 /// // Print information separately:
 /// println!("Type: {}", info.os_type());
 /// println!("Version: {}", info.version());
+/// println!("Edition: {:?}", info.edition());
+/// println!("Codename: {:?}", info.codename());
 /// println!("Bitness: {}", info.bitness());
 /// ```
 pub fn get() -> Info {
